==> 1.0.0.tar.gz: lib/src/navigator_observers/cruiser_stack_observer.dart <==
import 'dart:collection';
import 'package:cruiser/src/logger/cruiser_logger.dart';
import 'package:flutter/widgets.dart';

/// Experimental! might be removed or changed.
class CruiserStackObserver extends NavigatorObserver 
{
    final NavigatorState navigatorState;
    final List<Route> _routeStack = [];

    CruiserStackObserver({this.navigatorState,});

    @override
    void didPop(Route route, Route previousRoute) 
    {
        _routeStack.removeLast();
    }

    @override
    void didPush(Route route, Route previousRoute) 
    {
        _routeStack.add(route);
    }

    @override
    void didReplace({Route newRoute, Route oldRoute}) 
    {
        int oldIndex = _routeStack.indexOf(oldRoute);
        _routeStack.removeAt(oldIndex);
        _routeStack.insert(oldIndex, newRoute);
    }

    @override
    void didRemove(Route removedRoute, Route previousRoute) 
    {
        _routeStack.removeWhere((route) => route == removedRoute);
    }

    /// Returns the list of [Route]s represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<Route> getRouteStack() 
    {
        final stack = this._routeStack.reversed.toList();
        return UnmodifiableListView(stack);
    }

    /// Returns the list of route names represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<String> getRouteNameStack() 
    {
        final stack = this._routeStack.reversed.map((route) => route.settings.name).toList();
        return UnmodifiableListView(stack);
    }

    void prettyPrintStack() 
    {
        if (!CruiserLogger.instance.isLoggerEnabled) 
        {
            print("`AppLogger` should be enabled to print any Cruiser logs.");
        }

        if (this._routeStack.isEmpty) 
        {
            CruiserLogger.instance.info("Navigation stack is empty!");
        } 
        else 
        {
            String printableStack = _routeStack.fold("", (prevValue, route) 
            {
                return "$prevValue ${route.isFirst ? "" : "--->"} ${route.settings.name}";
            });

            CruiserLogger.instance.info("Navigation Stack: " + printableStack);
        }
    }
}

==> 1.2.1.tar.gz: lib/src/navigator_observers/cruiser_stack_observer.dart <==
import 'dart:collection';
import 'package:cruiser/src/logger/cruiser_logger.dart';
import 'package:flutter/widgets.dart';

/// Experimental! might be removed or changed.
class CruiserStackObserver extends NavigatorObserver 
{
    final NavigatorState navigatorState;
    final List<Route> routeStack = [];

    CruiserStackObserver({this.navigatorState,});

    @override
    void didPop(Route route, Route previousRoute) 
    {
        routeStack.removeLast();
    }

    @override
    void didPush(Route route, Route previousRoute) 
    {
        routeStack.add(route);
    }

    @override
    void didReplace({Route newRoute, Route oldRoute}) 
    {
        int oldIndex = routeStack.indexOf(oldRoute);
        routeStack.removeAt(oldIndex);
        routeStack.insert(oldIndex, newRoute);
    }

    @override
    void didRemove(Route removedRoute, Route previousRoute) 
    {
        routeStack.removeWhere((route) => route == removedRoute);
    }

    /// Returns the list of [Route]s represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<Route> getRouteStack() 
    {
        final stack = this.routeStack.reversed.toList();
        return UnmodifiableListView(stack);
    }

    /// Returns the list of route names represented as a stack of routes currently
    /// push by Navigator.
    ///
    /// Head and tail of list are bottom and top of stack respectively.
    UnmodifiableListView<String> getRouteNameStack() 
    {
        final stack = this.routeStack.reversed.map((route) => route.settings.name).toList();
        return UnmodifiableListView(stack);
    }

    void prettyPrintStack() 
    {
        if (!CruiserLogger.instance.isLoggerEnabled) 
        {
            print("`AppLogger` should be enabled to print any Cruiser logs.");
        }

        if (this.routeStack.isEmpty) 
        {
            CruiserLogger.instance.info("Navigation stack is empty!");
        } 
        else 
        {
            String printableStack = routeStack.fold("", (prevValue, route) 
            {
                return "$prevValue ${route.isFirst ? "" : "--->"} ${route.settings.name}";
            });

            CruiserLogger.instance.info("Navigation Stack: " + printableStack);
        }
    }
}
